@@ -8,7 +8,7 @@ from .log import logger
 HEADER_ATTRS = OrderedDict([
     ('magic', ('I', 2037952207)),
     ('version', ('I', 0)),
-    ('body_len', ('I', 0)),
+    ('_body_len', ('I', 0)),
     ('cmd', ('i', 0)),
     ('ret', ('i', 0)),
     ('reserve_str', ('32s', ''))
@@ -47,9 +47,9 @@ class Box(object):
     @property
     def body_len_key(self):
         """
-        默认是 body_len，但也支持修改，只要把这个覆盖就可以了
+        默认是 _body_len，但也支持修改，只要把这个覆盖就可以了
         """
-        return 'body_len'
+        return '_body_len'
 
     @property
     def header_len(self):
@@ -57,7 +57,7 @@ class Box(object):
 
     @property
     def packet_len(self):
-        return self.header_len + getattr(self, self.body_len_key)
+        return self.header_len + self.body_len
 
     @property
     def body(self):
@@ -68,6 +68,10 @@ class Box(object):
         self._body = value
         setattr(self, self.body_len_key, len(self._body))
 
+    @property
+    def body_len(self):
+        return getattr(self, self.body_len_key, None)
+
     def pack(self):
         """
         打包
